@@ -65,7 +65,7 @@ describe 'watcher' do
           :kombu_compression                  => 'gzip',
           :notification_transport_url         => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_topics                => 'notifications',
-          :ensure_package                     => '2012.1.1-15.el6',
+          :package_ensure                     => '2012.1.1-15.el6',
         }
       end
       it 'configures rabbit' do
@@ -126,8 +126,10 @@ describe 'watcher' do
 
       it 'configures rabbit' do
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_watcher_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
+        is_expected.to contain_oslo__messaging__rabbit('watcher_config').with(
+          :rabbit_use_ssl     => '<SERVICE DEFAULT>',
+        )
       end
     end
 
@@ -141,11 +143,13 @@ describe 'watcher' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/etc/ca.cert')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/etc/certfile')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/etc/key')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+        is_expected.to contain_oslo__messaging__rabbit('watcher_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '/etc/ca.cert',
+          :kombu_ssl_certfile => '/etc/certfile',
+          :kombu_ssl_keyfile  => '/etc/key',
+          :kombu_ssl_version  => 'TLSv1',
+        )
       end
     end
 
@@ -155,11 +159,13 @@ describe 'watcher' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_watcher_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('watcher_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
@@ -171,7 +177,6 @@ describe 'watcher' do
 
       context 'with default parameters' do
         it 'configures amqp' do
-          is_expected.to contain_watcher_config('DEFAULT/rpc_backend').with_value('amqp')
           is_expected.to contain_watcher_config('DEFAULT/transport_url').with_value('amqp://amqp_user:password@localhost:5672')
           is_expected.to contain_watcher_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_watcher_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
@@ -208,7 +213,6 @@ describe 'watcher' do
       end
 
       it 'configures amqp' do
-        is_expected.to contain_watcher_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_watcher_config('DEFAULT/transport_url').with_value('amqp://amqp_user:password@localhost:5672')
         is_expected.to contain_watcher_config('oslo_messaging_amqp/idle_timeout').with_value('60')
         is_expected.to contain_watcher_config('oslo_messaging_amqp/trace').with_value('true')
